# Rocketman

A lightweight API wrapper for the r/SpaceX API

# Installation

**Python 3.9 or higher is recommended**

```
python3 -m pip install rocketman
```

Clone repository:

```
$ git clone https://github.com/Batucho/Rocketman
```

**Feel free to contribute or inform any bug!**
